@@ -1,4 +1,42 @@
 
+Vue.component( 'upload-field', {
+    template: '#upload-field',
+    props: {
+        name: {
+            required: true
+        },
+        value: {
+            required: true
+        },
+        disabled: {
+            type: 'boolean',
+            default: false
+        },
+    },
+    data: function () {
+        return { };
+    },
+    methods: {
+        uploadFile: function (event) {
+            var form = new FormData();
+            form.append( 'upload', event.target.files[0] );
+            $.ajax( {
+                method: 'POST',
+                url: location.pathname + '/upload',
+                data: form,
+                processData: false,
+                contentType: false,
+                context: this
+            } )
+            .then(
+                function ( data ) {
+                    this.$emit( 'input', data );
+                }
+            );
+        },
+    }
+} );
+
 Vue.component('edit-field', {
     template: '#edit-field',
     props: {
@@ -67,6 +105,9 @@ Vue.component('edit-field', {
             else if ( this.schema.format == 'markdown' ) {
                 fieldType = 'markdown';
             }
+            else if ( this.schema.format == 'filepath' ) {
+                fieldType = 'file';
+            }
         }
         else if ( schemaType == 'integer' || schemaType == 'number' ) {
             fieldType = 'number';
@@ -633,11 +674,8 @@ var app = window.Yancy = new Vue({
         createBlankItem: function () {
             var schema = this.currentSchema,
                 item = {};
-            if ( schema.example ) {
-                return schema.example;
-            }
             for ( var k in schema.properties ) {
-                item[k] = null;
+                item[k] = schema.properties[k].default || null;
             }
             return item;
         },
